%--------------------------------------------------------------------------
%   Name:           sys_link_simu
%   Type:           script
%   Description:    This is the starting program of the simulator. It
%   initializes the path variables, sets the link and system level
%   simulation paramters. 
%                   It needs to verify whether the particilar link level
%                   simulation has been done or not. If the particular link
%                   level simulation is not done then it runs through the
%                   link level simulator, prepares the thresholds and
%                   lookup tables.
%                   Then it starts the system level simulator. If results exists it
%                   does not re-run the system level simulator. It 
%                   only runs the system level simulator when the results
%                   are not ready.
%                   Once the link and system level results are ready, then
%                   it runs through the analysis files to generate the
%                   results which shows different performance comparisons
%                   and saves the figures in a separate folder.
%--------------------------------------------------------------------------
% top-level simulation file
% 1. initialize parameters
% 2. if necessary, do link-level simulation
%    a. find threshold
%    b. find additional margin
% 3. system-level simulation
% 4. result analyse
% suvra sekhar das: suvra.das@gmail.com 
% yy, 01-july-2007
clear all;close all;clc
%% load origional matlab path
if ~exist('path_org','file')
    Root_path = [pwd,'/..'];
    P = path;
    save('path_org','P','Root_path');
else
    load path_org;
end
%% test case
test_case = 1;
switch test_case
    case 1
        cf = 2e9; % carrier frequency
        velo = 30; % average UE velocity in kmph
        fd = round(velo * 5/18 / 3e8 * cf); % Doppler frequency in Hz
        t_rms = 0.5; % Delay spread in us
        F_LA = 4; % LA per frame
        F_PA = 1; % LA per frame
        BO_dB = 0; % Power BackOff
        use_HPA_flg = 0; % power amplifyer
        flg_offset = 0; % Carrier frequency offset
        flg_csi_err = 0; % CSI estimation error
        BW = 5e6; % Bandwidth
        N = 512; % FFT size
        subN = 16; % sub-channel size
        cp_l = 128; % CP length in terms of sub-carriers
        
        %Nsymbol = 6; % No. of symbols per frame
        state = 1; % 1 SISO; 2 MRC; 3 Alt2x1; 4 EGC (not used); 5 AS2x1; 6 Alt2x2; 7 AS 2x2;
        targetFER = 0.05; % target Block Error Rate
        chnums = 1000; % No. of channel realizations
        sampling_rate = 1.536; % over-sampling factor
        DELAY = 4; % Feedback Delay in terms of OFDM symbols
        Ts = (N + cp_l) / (BW * sampling_rate);
        T_frame=0.5e-3;%Frame duration in seconds. This is the basic unit for a block.%Tf = Ts * Nsymbol;
        Tf=T_frame;

    case 2
        cf = 2e9; % carrier frequency
        velo = 30; % average UE velocity in kmph
        fd = round(velo * 5/18 / 3e8 * cf); % Doppler frequency in Hz
        t_rms = 1; % Delay spread in us
        F_LA = 1; % LA per frame
        F_PA = 1; % LA per frame
        BO_dB = 0; % Power BackOff
        use_HPA_flg = 0; % power amplifyer
        flg_offset = 0; % Carrier frequency offset
        flg_csi_err = 0; % CSI estimation error
        BW = 5e6; % Bandwidth
        N = 512; % FFT size
        subN = 12; % sub-channel size
        cp_l = 36; % CP length in terms of sub-carriers
        
        state = 1; % 1 SISO; 2 MRC; 3 Alt2x1; 4 EGC (not used); 5 AS2x1; 6 Alt2x2; 7 AS 2x2;
%        targetFER = 0.05; % target Block Error Rate
        targetFER = 0.1; % target Block Error Rate
        chnums = 1000; % No. of channel realizations
        sampling_rate = 1.536; % over-sampling factor
        DELAY = 4; % Feedback Delay in terms of OFDM symbols
        Ts = (N + cp_l) / (BW * sampling_rate);
        T_frame=1e-3;%Frame duration in seconds. This is the basic unit for a block.
        Tf=T_frame;
        %Tf = Ts * Nsymbol;
%
    otherwise
        disp('Unknown test case')
end
Nsymbol = floor(Tf/Ts); % No. of symbols per frame

Comm_conf = ...
    comm_config(fd,t_rms,F_LA,F_PA,BO_dB,use_HPA_flg,flg_offset,flg_csi_err,BW,cf,N,subN,cp_l,Nsymbol,state,targetFER,chnums,sampling_rate,DELAY,Ts,Tf);
%% exist link-lv result or not
% % % allow_load_oldtab = 1;%0;
%%% allow_load_oldtab = 0;%0;
allow_load_oldtab = 1;%0;

filename = ['table_','s',num2str(Comm_conf.state),'_f',num2str(Comm_conf.fd),'_t',num2str(Comm_conf.t_rms),'_N',num2str(Comm_conf.subN),'_L',num2str(Comm_conf.F_LA),...
    '_E',num2str(Comm_conf.flg_csi_err),...
    'c',num2str(Comm_conf.flg_offset),'D',num2str(Comm_conf.DELAY),'BO',num2str(Comm_conf.BO_dB),'HPA',num2str(Comm_conf.use_HPA_flg),'_BLER',num2str(Comm_conf.targetFER),'.mat'];
% filename = ['table_','s',num2str(Comm_conf.state),'_f',num2str(Comm_conf.fd),'_t',num2str(Comm_conf.t_rms),'_N',num2str(Comm_conf.subN),'_L',num2str(Comm_conf.F_LA),...
%     'P',num2str(Comm_conf.F_PA),'_E',num2str(Comm_conf.flg_csi_err),...
%     'c',num2str(Comm_conf.flg_offset),'D',num2str(Comm_conf.DELAY),'BO',num2str(Comm_conf.BO_dB),'HPA',num2str(Comm_conf.use_HPA_flg),'_BLER',num2str(Comm_conf.targetFER),'.mat'];
filepath = [Root_path,'/sys_link_result/link_lv_result','/',filename];
if allow_load_oldtab && exist(filepath,'file'),
    load(filepath); % exist link-level result, load it
else
    % link-level simulation first
    setpath(P,Root_path,1);
    path(path,[Root_path,'/comm_funcs']);
    [LA_thres, BLER_SINR_map] = func_link_lv_simu(Comm_conf,Root_path,allow_load_oldtab);
end
%% do if LA rate ~= PA rate
if Comm_conf.F_LA ~= Comm_conf.F_PA
    LA_thres_store = LA_thres;
    BLER_SINR_map_store = BLER_SINR_map;
    F_LA_store = Comm_conf.F_LA;
    Comm_conf.F_LA = Comm_conf.F_PA;
    filename = ['table_','s',num2str(Comm_conf.state),'_f',num2str(Comm_conf.fd),'_t',num2str(Comm_conf.t_rms),'_N',num2str(Comm_conf.subN),'_L',num2str(Comm_conf.F_LA),...
        '_E',num2str(Comm_conf.flg_csi_err),...
        'c',num2str(Comm_conf.flg_offset),'D',num2str(Comm_conf.DELAY),'BO',num2str(Comm_conf.BO_dB),'HPA',num2str(Comm_conf.use_HPA_flg),'_BLER',num2str(Comm_conf.targetFER),'.mat'];
    filepath = [Root_path,'/sys_link_result/link_lv_result','/',filename];
    if allow_load_oldtab && exist(filepath,'file'),
        load(filepath); % exist link-level result, load it
    else
        % link-level simulation first
        setpath(P,Root_path,1);
        path(path,[Root_path,'/comm_funcs']);
        [LA_thres, BLER_SINR_map] = func_link_lv_simu(Comm_conf,Root_path,allow_load_oldtab);
    end
    Comm_conf.F_LA = F_LA_store;
    LA_thres(:,1) = 1/2 * LA_thres(:,1) + 1/2 * LA_thres_store(:,1);
    %BLER_SINR_map(:,2:end-1) = 1/2 * BLER_SINR_map(:,2:end-1) + 1/2 * BLER_SINR_map_store(:,2:end-1);
end
%%%%% init LUT
st_initConfig = init_tables(LA_thres,BLER_SINR_map);

%% sys-lv simulation
setpath(P,Root_path,2);
path(path,[Root_path,'/comm_funcs']);
sys_test_case = 1;
switch sys_test_case
    case 1
        test_possible_user_numbers = 4; % No. of active UEs
        test_possible_user_velocities = velo; % UE velocity in kmph, should consider Doppler and Carrier frequency
        scenario_ix = 1; % 1 micro; 2 macro1; 3 macro3;
        RA_ix = 2; % RA index. 1 RR; 2 PF; 3 MX; 4 PF2;
        start_Drop = 1; % start index for Drops
% % %         end_Drop = 6;   % end index for Drops
        end_Drop = 2
end

% Call the System Simulator
% if the system simulator needs to be run considering that link level
% results be re-used (loaded from previous run) which is usually desired
% then comment out the line "if ~allow_load_oldtab" and also the line
% "end" which encapsulate the call to the "function func_sys_lv_simu"
% If only the results of the system simlator needs to be analyzed then
% uncomment the lines stated above.

%if ~allow_load_oldtab
func_sys_lv_simu(test_possible_user_numbers,test_possible_user_velocities,scenario_ix,RA_ix,Root_path,st_initConfig,Comm_conf,start_Drop,end_Drop);
%end


%% analyse result
path(P,[Root_path,'/analyse_result']);
% % % MaxSaveIndex = 60; % consider the total simulation duration in
% test_defination                   
% Check the number of data samples i.e. index of
% "saveIndex1.mat" etc in the "\user_gain_info_and_distance" folder of the sys_lv_result folder 
MaxSaveIndex = 30; % consider the total simulation duration in test_defination
save_info_factor = 1000; % refer to test_defination
loaddir=[Root_path,'/sys_link_result/sys_lv_result'];;%loaddir=[Root_path,'/sys_link_result/sys_lv_result/'];
savedir = [Root_path,'/sys_link_result/sys_lv_result_anls'];%savedir = [Root_path,'/sys_link_result/sys_lv_result_anls/'];

%%% overwrite_old = 1;
overwrite_old = 0;
if Comm_conf.state == 1,
    MIMO = 'SISO';
elseif Comm_conf.state == 2,
    MIMO = 'MRC';
else
    disp('not implemented');
end
UE = test_possible_user_numbers;
load_part2(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,savedir,start_Drop,end_Drop,overwrite_old,MaxSaveIndex,save_info_factor,Comm_conf)
loaddir=[Root_path,'/sys_link_result/sys_lv_result_anls'];
av_factor = 20;
result = []; fileidx = 0;
path(P,[Root_path,'/comm_funcs']);
% each time run only one of the followings
figdir='/../figs/';
res_bler_NoUEOUT(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,Comm_conf,figdir);
res_bs_powerad(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);
% res_bs_sinr(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf);
res_cdf_instTP(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);
res_cdf_of_uetp(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,Comm_conf,figdir);
res_corr(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,Comm_conf,figdir)
res_fair(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);
res_tp_vs_sinr(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);
res_ue_alive(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir)
res_ue_sinr(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);

%res_ue_sinr_CDF(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf,figdir);
%res_ue_sinr_CDF(RA_ix,UE,Comm_conf.F_LA,MIMO,loaddir,result,fileidx,av_factor,Comm_conf);
