%__________________________________________________________________________
% Type:                 :   File Header
% File name             :   initConfig
% File Description      :   Holds the data structure with initial values
%                           for variables that are used in the simulation
%__________________________________________________________________________




%__________________________________________________________________________
% Type                  :   Variable Header
% Variable Type         :   Structure
% Description           :   Contains initial values of important
%                           configuration variables
%__________________________________________________________________________




%choice of scheduling algorithm
% 0 fixed modulation with round robin scheduling with
% equal number of sub carriers allocated to each
% user
% 1, Round robin scheduling, equal number of sub carriers, SFN, fix power,
% only rate adaptation with FER constraint, throughput maximization
% 2, Round Robin scheduling, equal number of sub carriers, SFN, fix power,
% only rate adaptation, no FER constraint, therefore look up table from the
% Throughput curves... for rate decision....

switch test_resource_allocation
    case 'RR'
        SchedulingAlgoChoice=2;
    case 'MAXCI'
        SchedulingAlgoChoice=4;
    case 'PF'
        SchedulingAlgoChoice=5;
     case 'PF2'
        SchedulingAlgoChoice=6;
   otherwise
        sprintf(' resource allocation algorithm is not set propertly \n')
        break
end




%-------------------------------------------------------------------------%
%                                                                         %
%                   .-------------------------------.                     %
%                   | SETTINGS ON THE SYSTEM LEVEL  |                     %
%                   '-------------------------------'                     %
%                                                                         %
%-------------------------------------------------------------------------%





%G factor calculation Method
% 'nofsf' does not use frequency selective fading information.
% 'fsf' uses frequency selective fading channel for measurement
% this parameter is used in the ofdm_simulator....to call the appropriate update_mobiles..... function so that
% If g factor is to be measured, normal simulation won't run
st_initConfig.measure_g_factorFlg=test_g_factor_flg;%'no';% 'yes'
switch st_initConfig.measure_g_factorFlg
    case 'yes'
        % If the above is 'yes' then the next one is used otherwise not
        st_initConfig.g_factor_calculation_methodFlg='nofsf';%'fsf'
        %Handoff to be used or not
        % 'handoff' to be used to indicate users will be distributed across the whole area and
        % wrap-around model will be used in the path gain calculations
        % 'nohandoff' to be used in main simulations mostly, when wrap around model will NOT be used
        % users will be located in the central cell.
        st_initConfig.handOffFlg='handoff';
    case 'no'
        st_initConfig.handOffFlg='nohandoff';
    otherwise
        sprintf('measure_g_factorFlg not set correctly \n')
        break
end



% Cellular configuration
% 'macro1' means large cell with ISD of 500 m
% 'macro3' means large cell with ISD of 1732 m
% 'micro1' means small cell with ISD of 130 m
% most important to note here is that the path loss model will change accordingly
% the correlation, number of sector will depend on this as well.
st_initConfig.scenarioLabel=test_scenario;%'macro1';%'micro1';%'macro1';%'micro1';%'macro';%'micro';%'macro';%'micro'

% Frequency planning and power distribution
% This is to be used while calculating the received SINR
% The link budget needs to be done
%'fractionalSFNannular';% SFN + fractional reuse in annular cellular format
%'fractionalSFN';% each cell uses only a
%fraction of the total bandwidth, but the total
%bandwidth is accesible
st_baseStation.FreqPlan =  test_FRF;% 'SFN' ; % single frequency network


% channel estimation error inclusion method.
% It can take the values 'predefined' or 'runtime'
% in case of 'predefined' a fixed noise variance will be added to the
% channel estimation, i.e. sinr estimated at the receiver. On the other
% hand, the value 'runtime' indicates the true SINR is used to add an
% equivalent amount of noise in the sinr estimate at the recevier, which is
% used for finding the modulation and coding level.
st_initConfig.channelEstErrRxMethod='runtime';%'predefined';'runtime'

switch st_initConfig.channelEstErrRxMethod
    case 'runtime'
    case 'predefined'
        st_initConfig.channelEstErrRxValdB=10;%
    otherwise
        sprintf('channelEstErrRxMethod is not configured properly \n')
        break
end


% Head Margin for power control in Downlink OFDMA
% The value is in dB will indicate how much is the power level below the maximum power level to be used in general cases
% This will leave space for downlink power control.
st_initConfig.headPowMargindB=0;

% Number of mobiles to be used in the simulation run
NumberActiveMobiles = test_nu_active_users;%2; % [2 4 8 16 32 64]

% The average velocity of the users
fixVeloUnderTestkmph = test_avg_velo_kmph;%30; % velocity in kmph

% File size that each user needs to transmit
st_initConfig.MaxFileSz = test_file_size_per_user_bits;%0.05*1024*8;%2*1024*8;%2e6; % maximum file size for each mobile

% Values to be used in case of fixed modulation tests
FixMod='qpsk';%'qam16'; % not much important, Used to compare against fixed modulations
FixRate='1/2'; %'1/3';'1/2';'2/3'



%Time counter 
st_initConfig.currTimeinSec=0;

% The sub frame size to be used in the simulations, the value to be used is
% in seconds
% This is the test duration of the minimum frame in seconds
% FEC block is of this duration.

st_initConfig.subFramePeriod = Comm_conf.Tf;
%%
% The frame period in seconds,
% which consists of several sub frames
% The modulation and coding may be kept fixed during this period. while
% power control may be varied at a different rate.
% The scheduling allocation period can be controlled accordingly
st_initConfig.FramePeriod =test_F_LA*st_initConfig.subFramePeriod;%0.5e-3;% [0.5e-3 1e-3 2e-3 5e-3 10e-3 20e-3 40e-3]
%st_initConfig.FrameToSubTimeFrameRatio=test_F_LA;%st_initConfig.FramePeriod/st_initConfig.subFramePeriod;
%The maximum duration of the frame in seconds
% This is done to keep a cross check
%% define as the current frame period,,, not needed
st_initConfig.maxFramePeriod = st_initConfig.FramePeriod;
%%
% The simulation must run for as many seconds as specified below
st_initConfig.simulationPeriod = test_simulation_period_factor*st_initConfig.subFramePeriod; % This time is in seconds

% Total number of Frames transmitted in the simulation period.
st_initConfig.nusubFrames = test_simulation_period_factor;%floor(st_initConfig.simulationPeriod/st_initConfig.subFramePeriod);%2;1e1;1e2;1e3;1e4;1e5;10;%50;%125;%10;%150;%200;%15000;


% Carrier Frequency
st_initConfig.cf = Comm_conf.cf;%3.5e9;
% System Bandwidth
st_initConfig.bw = Comm_conf.BW;
st_initConfig.nuFFT = Comm_conf.N;
% Sampling frequency used is slightly higher than the bandwidth, while
% guard bands are used at both ends and hence a good filter can be designed
% easily while the frequency efficiency can be made very high
st_initConfig.samplingFreq = Comm_conf.sampling_rate*st_initConfig.bw;

% System Sampling Period
st_initConfig.tSample = 1/st_initConfig.samplingFreq;

%Number of points in the FFT
switch st_initConfig.bw
    case {5e6}
        %st_initConfig.nuFFT = 512;
        st_initConfig.nuSubCarr = 301;
    case {10e6}
        %st_initConfig.nuFFT = 1024;
        st_initConfig.nuSubCarr = 601;
    otherwise
        sprintf(' Bandwidth not set correctly \n')
        break;
end


% The number of non zero sub carriers.
% Currently all are considered for data transmission while later pilots
% will be considered. Now the overhead calculations will take care of the
% pilot sub carriers.

% the sub carrier indices
st_initConfig.sub_cars = 1:st_initConfig.nuSubCarr;%find(st_baseStation.allocation==1);%lp_nmob);

% Sub carrier bandwidth / spacing
st_initConfig.subCarrBw = st_initConfig.samplingFreq/st_initConfig.nuFFT;

% Number of data sub carriers
st_initConfig.nuDataSubCarr = st_initConfig.nuSubCarr;

% OFDM symbol Duration % T_f
st_initConfig.tf = 1/st_initConfig.subCarrBw;

%Guard Period / Cyclic Prefix duration
% currently being taken as 25% of the OFDM symbol duration
st_initConfig.tg = Comm_conf.cp_l/st_initConfig.nuFFT*st_initConfig.tf;

% symbol Duration =Data Duration + Guard Period, T_s = T_f+T_g
st_initConfig.tSymb  = st_initConfig.tf + st_initConfig.tg;

%Number of OFDM symbols in a sub frame
st_initConfig.nuOfdmSymbPerSubFrame= Comm_conf.Nsymbol;%round(st_initConfig.subFramePeriod/st_initConfig.tSymb) ;%4; % for debugging purpose only!


% Parameters needed for pathgain initialization. Eg
% Calculate the gain between bases and mobiles
switch st_initConfig.scenarioLabel
    case 'micro1'
        st_initConfig.isd = 130;%1732;%1732;%500;% inter site distance
        st_initConfig.maxPowBSdBm=35+6-st_initConfig.headPowMargindB;% 38+6-st_initConfig.headPowMargindB;
        st_initConfig.dmin=10;%in m, min distance between BS and UE
        st_initConfig.attConst=-7;%-128;%-21;
        st_initConfig.alpha=5.6;
        st_initConfig.sigma=10;%4;
        % st_initConfig.sigma_y=0;%4; % This is for rms delay spread
        st_initConfig.raa=0;%0.5;
        st_initConfig.corrDist=25;%110; % correlation distance
        st_initConfig.sps=1;% sectors per site:  1 for micro cell, 3 for macro cell
        st_initConfig.km=2;%2;%1; % parameter for rohmbus,
        st_initConfig.lm=3;%3;%2; % parameter for rohmbus,
        st_initConfig.nuCluster=1 ;

    case 'macro1'
        st_initConfig.isd = 1732;%500;%1732;%;%1732;%500;%1732;%500;%1732;%500;%1732;%500;%1732;%1732;%500;% inter site distance
        st_initConfig.maxPowBSdBm=43+14-st_initConfig.headPowMargindB; % 38 dBm for 10MHz
        st_initConfig.dmin=35;
        scaleFac=10.5;
        st_initConfig.attConst=-35.3;%-15.3;%-35.3;%-15.3;%-35.3;%-15.3;%-35.3;%900 7.2;%-35.3;%2ghz 15.3;%-35.3;%-128;%-21;
        st_initConfig.alpha=3.76;
        st_initConfig.sigma=8;%4;
        % st_initConfig.sigma_y=0;%4; % This is for rms delay spread
        st_initConfig.raa=0.5;
        st_initConfig.corrDist=50;%110; % correlation distance
        st_initConfig.sps=3;% 1 for micro cell, 3 for macro cell
        st_initConfig.km=2;%2;%1; % parameter for rohmbus,
        st_initConfig.lm=3;%3;%2; % parameter for rohmbus,
        st_initConfig.nuCluster=1 ;
    % what's the difference between macro2 and macro3?
    case 'macro3'
        st_initConfig.isd = 1732;%500;%1732;%;%1732;%500;%1732;%500;%1732;%500;%1732;%500;%1732;%1732;%500;% inter site distance
        st_initConfig.maxPowBSdBm=43+14-st_initConfig.headPowMargindB; % 38 dBm for 10MHz
        st_initConfig.dmin=35;
        scaleFac=10.5;
        st_initConfig.attConst=-35.3;%-15.3;%-35.3;%-15.3;%-35.3;%-15.3;%-35.3;%900 7.2;%-35.3;%2ghz 15.3;%-35.3;%-128;%-21;
        st_initConfig.alpha=3.76;
        st_initConfig.sigma=8;%4;
        % st_initConfig.sigma_y=0;%4; % This is for rms delay spread
        st_initConfig.raa=0.5;
        st_initConfig.corrDist=50;%110; % correlation distance
        st_initConfig.sps=3;% 1 for micro cell, 3 for macro cell
        st_initConfig.km=2;%2;%1; % parameter for rohmbus,
        st_initConfig.lm=3;%3;%2; % parameter for rohmbus,            
        st_initConfig.nuCluster=1 ;

    otherwise
        sprintf('scenario setting not configured properly \n')
        break
end
% Configure the antenna angular gain vector at the sector BS
theta=[0:180 -179:-1];%[-180:179];%[0:180 -179:-1];%[0:180 -179:-1];% [-180:179];%[0:180 -179:-1];%[-180:179];%;%[0:180 -179:-1];%[-180:179];%[0:180 -179:-1];%-180:179;
switch st_initConfig.sps
            case {3}
                st_initConfig.cellRadius=st_initConfig.isd/3; % Cell radius on meters
                thetaThreeDb=70; % degrees
                Am=20; %dB
                st_initConfig.lobeVector = -min(12*((theta/thetaThreeDb).^2),Am);               
            case {1}
                st_initConfig.cellRadius=st_initConfig.isd/1.732; % Cell radius on meters
                st_initConfig.lobeVector = zeros(360,1); % omnidirectional antenna;
    otherwise
        sprintf('Number of sectors not defined properly\n')
        break;
end


st_initConfig.ncell_per_cluster = st_initConfig.km^2+ st_initConfig.lm^2+st_initConfig.km*st_initConfig.lm;

% identify the desired Base station for the simulation case
switch st_initConfig.ncell_per_cluster
    case 7
        st_initConfig.desiredBsIdx=2;    
        st_initConfig.scaleFactor=7;
    case 19
        st_initConfig.desiredBsIdx=5;
        st_initConfig.scaleFactor=9;
    case 37
        st_initConfig.desiredBsIdx=10;
        st_initConfig.scaleFactor=15;
    otherwise
        sprintf(' ncells per cluster is not defined correctly \n')
        break
end

% change the coverage area scale factor depending on whether g factor is
% being measured by handoff or not
switch st_initConfig.handOffFlg
    case 'nohandoff' % in case of no handoff the users are limited to a 
                     % certain area but the g-factor distribution must be
                     % maintained
        switch st_initConfig.scenarioLabel
            case {'macro1','macro3'}
                st_initConfig.scaleFactor=4;% to match the SINR (g factor) distribution
            case {'micro1'}
                st_initConfig.scaleFactor=2;%2;% to match the SINR (g factor) distribution
            otherwise
        end
    case 'handoff'% for G-factor calculations
        % scalefactor already defined earlier
    otherwise
        sprintf('HandOff setting not configured correctly\n')
        break
end

%defining empty variable for area over which users will be generated
st_initConfig.rombvec=nan; % rohmbus for coverage area.


% Rms delay spread model: Can�t do anything here, but put in the channel impulse response generator
% The power decay profile: 	�exponential�
% 				�pdp�  This means power decay
% Can�t do anything here but must be put into channel impulse response generator
% Based on the value, the 'channel' object will be initialized
% Another value can be 'pdp'
% If 'exponenitial' is used, then the rms
% delay spread value has to be generated
% by the model for rms delay spread
% which is a function of the distance
% between the mobile and the base station
st_initConfig.pdp = 'exponential' ; 





%-------------------------------------------------------------------------%
%                                                                         %
%                .---------------------------------------.                %
%                | SETTINGS ON THE BASE STATION (Node B) |                %
%                '---------------------------------------'                %
%                                                                         %
%-------------------------------------------------------------------------%




%Base Station max transmit power
st_initConfig.maxPowBS = 1e-3*(10.^(st_initConfig.maxPowBSdBm/10));% Converting logerithmic scale to linear scale.

% % POWER PER SUB CARRIER
st_initConfig.maxPowBsSubCdBm = st_initConfig.maxPowBSdBm - 10*log10(st_initConfig.nuSubCarr);%28.1;% as per wimax calculations
%st_initConfig.maxPowBsSubCarr = ((10.^(st_initConfig.maxPowBsSubCdBm/10))*1e-3)
st_initConfig.maxPowBsSubCarr = st_initConfig.maxPowBS/(Comm_conf.subN * floor(st_initConfig.nuSubCarr/Comm_conf.subN)); 

%Number of Sector Stations
st_initConfig.nuBs=st_initConfig.ncell_per_cluster*st_initConfig.nuCluster*st_initConfig.sps;% Number of base stations


% Number of antennas at the base station
% AS OF NOW USE ONLY ONE ANTENNA UNTILL PROPER ALGORITHMS ARE IMPLEMENTED
st_initConfig.nuAntennaBS = Comm_conf.T_div;%2; % This can be given values up to 12 !
% Location of base stations, this is kept here to run the system faster
st_initConfig.locBS=nan(1,st_initConfig.ncell_per_cluster);


%indexes of base stations which cause interference in the cell center
%region, and in case of reuse factor of one, in the outer region as well
%st_initConfig.listIntfBSIdx=[39 27 46 28 6 15 14 40 42 41 30 49 31 32 29 7 16 19 18 17];

%indexes of base stations which cause interference in the outer cell region
%in case of fractional reuse factor
%st_initConfig.listIntfBSFRFIdx=[40 41 31 29 7 16 18];

%Index of sectors
st_initConfig.listBs = 1:st_initConfig.nuBs;

% list of interfering base stations
st_initConfig.intfBsIdxvector = st_initConfig.listBs(st_initConfig.listBs~=st_initConfig.desiredBsIdx);




%-------------------------------------------------------------------------%
%                                                                         %
%                 .------------------------------------.                  %
%                 | SETTINGS ON THE USER EQUIPMENT (UE)|                  %
%                 '------------------------------------'                  %
%                                                                         %
%-------------------------------------------------------------------------%




%noise figure in receivers
st_initConfig.noiseFiguredB=9;
st_initConfig.noiseFigureLin=10^(st_initConfig.noiseFiguredB/10);
st_initConfig.noisePowerPerSubc=(1.3806503e-23)*300*st_initConfig.subCarrBw*st_initConfig.noiseFigureLin;
st_initConfig.noisePower=st_initConfig.noisePowerPerSubc*st_initConfig.nuSubCarr;

% UMTS Receiver sensitivity: Node B: -121dBm, Mobile -117dBm at BER of 10-3
% UMTS specs: Mobile peak power: Power class 1: +33 dBm (+1dB/-3dB) = 2W;
% class 2: +27 dBm, class 3: +24 dBm, class 4: +21 dBm
% WiMAX: receiver sensitivity: -30 dBm, 3.5 MHz bandwidth at 3.5 GHz/5 GHz
% WiMAX: Transmit power can vary!


% Number of mobiles:
st_initConfig.nuMob = NumberActiveMobiles;% 2e1; 1e4; % This can be varied. use 1e4  to check the
% coverage area in one shot

st_initConfig.dT = st_initConfig.tSymb ; %st_initConfig.subFramePeriod;%st_initConfig.tSymb ; % Interval at which the mobile
% locations are updated , we need to discuss this.

% Number of antennas at the mobiles:
% AS OF NOW USE ONLY ONE ANTENNA UNTILL PROPER ALGORITHMS ARE IMPLEMENTED
st_initConfig.nuAntennaMS =  Comm_conf.R_div;% ; % This can be varied.

st_initConfig.vMean = fixVeloUnderTestkmph; % average velocity of mobiles in kmph.
st_initConfig.vFactor = 1/3;
st_initConfig.max_veloms = (1+st_initConfig.vFactor)*st_initConfig.vMean;
st_initConfig.min_veloms = (1-st_initConfig.vFactor)*st_initConfig.vMean;

%st_initConfig.max_veloms = 50; %18/5*3e8/st_initConfig.cf/(10*st_initConfig.tSymb);
% This needs to be changed later
% when different mobiles can have
% different velocities
st_initConfig.aMean = st_initConfig.vMean*.01; % average acceleration of Mobiles

st_initConfig.doppMeanMax = st_initConfig.vMean*5/18*st_initConfig.cf/3e8;

% mobile locations,
st_initConfig.locMS=nan(st_initConfig.nuMob,1);

%Mobile velocities
st_initConfig.veloMS=nan(st_initConfig.nuMob,1);

% st_initConfig.rateReqMS=nan(st_initConfig.nuMob,1); % not being used now.
% st_initConfig.bitErrRateReqMS=nan(st_initConfig.nuMob,1);

st_initConfig.saveUserInfo_factor = 1000;%1000; % save user information per 100 subframes





%-------------------------------------------------------------------------%
%                                                                         %
%        .---------------------------------------------------.            %
%        | SETTINGS ON LINK ADAPTATION & RESOURCE ALLOCATION |            %
%        '---------------------------------------------------'            %
%                                                                         %
%-------------------------------------------------------------------------%





%st_initConfig.feedBackDelayRate = 10*st_initConfig.doppMeanMax; % Delay
% between CSI fed back to BS for LA and
% scheduling and use in subsequent
% frame Given in Hz
%  The above method of defining delay in terms of Doppler is good from
%  analysis point of view. But, when studying system, one should use real
%  parameters which are specified in the seconds as in the next variable.
st_initConfig.feedBackDelayInterval = st_initConfig.tSymb*Comm_conf.DELAY;%st_initConfig.FramePeriod;%1/st_initConfig.feedBackDelayRate;% The same as
% above but in seconds

% check if the feedback delay is less than one OFDM symbol, which is not
% valid. If it is so, then make it at least one OFDM symbol period
if (st_initConfig.feedBackDelayInterval*1e6) < (st_initConfig.tSymb*1e6)
    st_initConfig.feedBackDelayInterval = st_initConfig.tSymb;
    st_initConfig.feedBackDelayRate = 1/st_initConfig.feedBackDelayInterval;
end

% Compute the number of ofdm symbols equivalent of the update rate
st_initConfig.feedBackDelayIntervalNuOfdms = ceil(st_initConfig.feedBackDelayInterval/st_initConfig.tSymb);

% This value will be used to find mobile whose channel condition is bad.
% then other conditions will determine whether the mobile is to dropped
% from service or not
st_initConfig.SINR_Threshold=0; 


% Define the structure for channel , it will store the shadowing grid, and
% the tau_rms grid
st_channelGrid.epsilon = 0.5 ;% model parameter for tau_rms
st_channelGrid.T1 = 1.0e-6;% rms delay spread at a distance of 1 km in urban macro cell


%1 ; % 1 --> Very simple uniform resource allocation,
% a group of sub carriers is allocated to one user
% A random group is allocated to one user
% uniform power allocation across sub carriers
st_baseStation.nuSubCarrPerSubChan = Comm_conf.subN;%floor(st_initConfig.nuDataSubCarr/st_initConfig.nuMob);
st_baseStation.nuSubChannels = floor(st_initConfig.nuSubCarr/st_baseStation.nuSubCarrPerSubChan);

st_baseStation.tcNuSubFrames=test_pf_thpt_avg_time_window_factor;%100; % the averaging time is 50 Frame periods

st_baseStation.tc=st_initConfig.subFramePeriod*st_baseStation.tcNuSubFrames;
% Scheduling Algorithm
st_baseStation.scheduler_Algo  = SchedulingAlgoChoice; % Round Robin, but fixed modulation and coding rate

% This is the index, which rolls and is used in looking back the history of
% a mobile to terminate it
%st_initConfig.nuFrmPerSlot=max(50,st_baseStation.tcNuSubFrames);
st_initConfig.MAX_OFDM_SYMBOL_WAIT=test_user_time_out_period_factor;

%slot value should be at least 1 more than the drop/average value.
% for average per 2 frame, 3 values are needed to get the 2 differences.
% Same for drop user.
st_initConfig.nuFrmPerSlot=max(st_initConfig.MAX_OFDM_SYMBOL_WAIT + 1,st_baseStation.tcNuSubFrames)+1;


%The following variable from update_mobile_structure_before_frame.m has been shifted here
%st_initConfig.MAX_OFDM_SYMBOL_WAIT=min(test_user_time_out_period_factor,st_initConfig.nuFrmPerSlot-10);%st_initConfig.nuOfdmSymbPerFrame;%4*1;

switch st_baseStation.scheduler_Algo
    case 0 % Round Robin, but fixed modulation and coding rate
        st_baseStation.FixModulation=FixMod;
        st_baseStation.FixFec=FixRate; % Need to change the resource allocation codes
%         st_baseStation.nuSubCarrPerSubChan = 16;%floor(st_initConfig.nuDataSubCarr/st_initConfig.nuMob);
%         st_baseStation.nuSubChannels = st_initConfig.nuSubCarr/st_baseStation.nuSubCarrPerSubChan;
%         st_initConfig.nuMob = st_baseStation.nuSubChannels;
        if floor(st_baseStation.nuSubChannels/st_initConfig.nuMob)==0
            st_baseStation.nuSubChannelsMAX_RR=1;
        else
            st_baseStation.nuSubChannelsMAX_RR=floor(st_baseStation.nuSubChannels/st_initConfig.nuMob);
        end
    case {1 2}
        %st_baseStation.nuSubCarrPerMs = floor(st_initConfig.nuDataSubCarr/st_initConfig.nuMob);
        if floor(st_baseStation.nuSubChannels/st_initConfig.nuMob)==0
            st_baseStation.nuSubChannelsMAX_RR=1;
        else
            st_baseStation.nuSubChannelsMAX_RR=ceil(st_baseStation.nuSubChannels/st_initConfig.nuMob);
        end
    case 4
        % max c/I
        %         sub_channel_counter=0;
    case 5
        % Proportional Fair
        % Simple PF. with no constraints!
    otherwise
end
% st_initConfig.maxPowBsSubCarrSet = st_baseStation.nuSubCarrPerSubChan*(10.^(st_initConfig.maxPowBsSubCdBm/10))*1e-3;
% st_initConfig.noisePowerPerSubCarrSet = st_baseStation.nuSubCarrPerSubChan*st_initConfig.noisePowerPerSubc;
% rx_snr=10*log10(st_initConfig.noisePower/st_initConfig.maxPowBsRevCalc)
% rx_snr=10*log10(st_initConfig.noisePowerPerSubc/st_initConfig.maxPowBsSubCarr)
%
% allocation units
st_baseStation.allocation = nan(st_baseStation.nuSubChannels,st_initConfig.nuAntennaMS,st_initConfig.nuAntennaBS);

% rates as mentioned by LA for each mobile's link, each spatial + frequency
% domain link
st_baseStation.mod = nan(st_baseStation.nuSubChannels,st_initConfig.nuAntennaMS,st_initConfig.nuAntennaBS);
st_baseStation.fec = nan(st_baseStation.nuSubChannels,st_initConfig.nuAntennaMS,st_initConfig.nuAntennaBS);
st_baseStation.transmitPower = nan(st_baseStation.nuSubChannels,st_initConfig.nuAntennaMS,st_initConfig.nuAntennaBS);


switch (st_baseStation.FreqPlan)
    case 'SFN'
        %st_baseStation.transmitPower = 10^(st_initConfig.maxPowBSdBm/10)/(st_initConfig.nuDataSubCarr*st_initConfig.nuAntennaBS)*ones(st_initConfig.nuMob ,st_initConfig.nuDataSubCarr,st_initConfig.nuAntennaMS,st_initConfig.nuAntennaBS);
    case 'fractionalSFNannular'

    case 'fractionalSFN'
end

% st_measurement = nan;
% st_measurement.sinr_avg=zeros(1,round(1.5*st_initConfig.cellRadius));
% st_measurement.cnt = zeros(1,round(1.5*st_initConfig.cellRadius));
st_measurement.outageCnt = 0;
st_measurement.totalBitsSent = 0;
st_measurement.totalFramesinError=uint32(0);
st_measurement.sinrCnt =0 ;
st_measurement.sinrAvg = 0;
st_measurement.sinrAvgDist = 0;
st_measurement.amcCnt = 0 ;
st_measurement.mod = 0;
st_measurement.fec = 0;
st_measurement.mdfcDist = 0;

% Thresholds for non power adaptation scenario
% The throughput threshold look up is used to find the rate at a certain
% SNR in dB, the first column is the SNR, while the second column is the
% modulation order and the third column is the FEC rate
% @ 16 SUB CARRIERS IN ONE SUB CHANNEL @ 200 kmph
st_initConfig.lookUpTableMargindB=0;%1.5;%in dB
% initilize 5% FER lookup table
%init_tables;
%%%%%%%%%%%%%%%%%%%%%% yy added %%%%%%%%%%
st_initConfig.chnums_max = 10030;
st_initConfig.chnums_min = 30;
%st_initConfig.tast_file_size_max_ratio = tast_file_size_max_ratio;


%%
st_initConfig.F_LA = Comm_conf.F_LA;
st_initConfig.F_PA = Comm_conf.F_PA;
